/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is The Extension Manager.
 *
 * The Initial Developer of the Original Code is Ben Goodger. 
 * Portions created by the Initial Developer are Copyright (C) 2004-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Ben Goodger <ben@bengoodger.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
 /*
#################################
#		based on the original about.js		#
#		with some modifications for me		#
#								#
#################################
*/
function EM_NS(aProperty)
{
	return "http://www.mozilla.org/2004/em-rdf#" + aProperty;
}

function bmbextAboutInit()
{
	const gExtensionID = "urn:mozilla:item:{d9a65dd1-419b-4419-bba8-15fd1aec456a}";
	
	const gExtensionDB = window.opener.document.getElementById("extensionsView").database;
	const gAboutStringBundle = document.getElementById("bmbextAboutStrings");
	const gLangStringBundle = document.getElementById("bmbextLangStrings");
	const extensionsStrings = document.getElementById("extensionsStrings");
  
	const rdfs = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Components.interfaces.nsIRDFService);
	const extension = rdfs.GetResource(gExtensionID);
	
	var arc, element;
	
	/*
		EXTENSION NAME
	*/     
	arc= rdfs.GetResource(EM_NS("name"));
	var name = gExtensionDB.GetTarget(extension, arc, true);
	name = name.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
	document.title = extensionsStrings.getFormattedString("aboutWindowTitle", [name]);
	element = document.getElementById("extensionName");
	element.setAttribute("value", name);
	name = null;
	
	
	/*
		VERSION
	*/
	arc = rdfs.GetResource(EM_NS("version"));
	var version = gExtensionDB.GetTarget(extension, arc, true);
	version = version.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
	element = document.getElementById("extensionVersion");
	var versionSplit = version.split(".");
	if (versionSplit.length < 4)
	{
		element.setAttribute("value", extensionsStrings.getFormattedString("aboutWindowVersionString", [version]));
	}
	else
	{
		version = versionSplit[0] + "." + versionSplit[1] + "." + versionSplit[2] + " " + gLangStringBundle.getFormattedString("bmb-ext.aboutWindowBuildString", [versionSplit[3]]);
		element.setAttribute("value", extensionsStrings.getFormattedString("aboutWindowVersionString", [version]));
	}
	version = null; versionSplit = null;
	
	
	/*
		DESCRIPTION
	*/
	arc = rdfs.GetResource(EM_NS("description"));
	var description = gExtensionDB.GetTarget(extension, arc, true);
	if (description)
	{
		description = description.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
	}
	else
	{
		description = gLangStringBundle.getString("extensions." + BMB_GUID + ".description");
	}
	element = document.getElementById("extensionDescription");
	element.appendChild(document.createTextNode(description));
	description = null;
	
	
	/*
		CREATOR
	*/
	arc = rdfs.GetResource(EM_NS("creator"));
	var creator = gExtensionDB.GetTarget(extension, arc, true);
	if (creator)
	{
		creator = creator.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
		element = document.getElementById("extensionCreator");
		element.setAttribute("value", creator);
	}
	creator = null;
	
	
	/*
		CREATOR HOME PAGE URL
	*/
	arc = rdfs.GetResource(EM_NS("homepageURL"));
	var homepage = gExtensionDB.GetTarget(extension, arc, true);
	element = document.getElementById("extensionHomepage");
	if (homepage)
	{
		homepage = homepage.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
		element.setAttribute("homepageURL", homepage);
		element.setAttribute("tooltiptext", homepage);
	}
	else
	{
		element.hidden = true;
	}
	homepage = null;
	
	
	/*
		CONTIBUTORS / TRANSLATORS
	*/
	var items = [["translatorsBox", "translator", "extensionTranslators"], ["contributorsBox", "contributor", "extensionContributors"]];
	var itemIdx = 0;
	if (navigator.userAgent.search(/\/1\.(5|0)(\.[0-9]){0,2}/) != -1)
	{
		itemIdx = 1;
	}
	
	element = document.getElementById(items[itemIdx][0]);
	arc = rdfs.GetResource(EM_NS(items[itemIdx][1]));
	var targets = gExtensionDB.GetTargets(extension, arc, true);
	var target = {name: "", contrib: "", homepage: "", hpTitle: ""};
	
	var count = 0;
	while (targets.hasMoreElements())
	{
		count++;
		target.name = targets.getNext().QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
		target.contrib = gAboutStringBundle.getString("contributor#"+count+"_Contrib");
		target.homepage = gAboutStringBundle.getString("contributor#"+count+"_URL");
		target.hpTitle = gAboutStringBundle.getString("contributor#"+count+"_URLTitle");
		var hbox = document.createElement("hbox");
		var label1 = document.createElement("label");
		
		label1.setAttribute("value", target.name);				// value attribute does not work with created elements :-/
		if (target.contrib != "")
		{
			label1.setAttribute("value", target.name + ": " + target.contrib);
		}
		label1.className = "contributor";
		label1.flex = "1";
		label1.setAttribute("crop", "right");
		hbox.appendChild(label1);
		
		label1 = document.createElement("label");
		label1.setAttribute("value", " ");
		label1.setAttribute("class", "contributorHomepage");
		label1.setAttribute("style", "visibility:hidden;");
		if (target.homepage != "" && target.hpTitle != "")
		{
			label1.removeAttribute("style");
			label1.setAttribute("value", target.hpTitle);
			label1.setAttribute("homepageURL", target.homepage);
			label1.setAttribute("tooltiptext", target.homepage);
			label1.setAttribute("onclick","loadHomepage(event);");
		}
		hbox.appendChild(label1);
		element.appendChild(hbox);
	}
	if (itemIdx == 0)
	{
		document.getElementById(items[itemIdx][2]).value = gLangStringBundle.getString("translators.label");
		document.getElementById(items[1][2]).hidden = true;
	}
	else
	{
		document.getElementById(items[0][2]).hidden = true;
	}
	
	if (count == 0)
	{
		document.getElementById(items[itemIdx][2]).hidden = true;
	}
	arc = null;	element = null;
	targets = null; target = null;

	var acceptButton = document.documentElement.getButton("accept");
	acceptButton.label = extensionsStrings.getString("aboutWindowCloseButton");
}

function loadHomepage(aEvent)
{
	window.opener.openURL(aEvent.target.getAttribute("homepageURL"));
}
